@@ -38,7 +38,7 @@ else
   $use_yahoo = 1;
 }
 
-$VERSION = "0.12";
+$VERSION = '0.75';
 
 sub new
 {
@@ -391,11 +391,11 @@ Will update the stored conversion rate and timestamp by doing another conversion
 
 =head1 AUTHOR
 
-Earle Martin <EMARTIN@cpan.org>
+Earle Martin <hex@cpan.org>
 
 =over 4 
 
-=item L<http://purl.oclc.org/net/earlemartin/>
+=item L<http://downlode.org/Code/Perl/>
 
 =back
 
@@ -405,9 +405,9 @@ See the credits for L<Locale::Object>.
 
 =head1 LEGAL
 
-Copyright 2003-2004 Earle Martin. All rights reserved.
+Copyright 2003-2007 Earle Martin. All rights reserved.
 
-This module is released under the same license as Perl itself, and is provided on an "as is" basis. The author makes no warranties of any kind, either expressed or implied, as to the accuracy and/or utility of any results obtained from its use. However, if you do find something wrong with the results, please let the author know. Thanks.
+This module is released under the same license as Perl itself, and is provided on an "as is" basis. No warranty of any kind is made, either expressed or implied, as to the accuracy and/or utility of any results obtained from its use. However, if you do find something wrong with the results, please let the author know. Thanks.
 
 =cut
 
