@@ -11,7 +11,7 @@ use base qw( Locale::Object );
 use Locale::Object::Country;
 use Locale::Object::DB;
 
-$VERSION = "0.132";
+$VERSION = '0.75';
 
 my $db = Locale::Object::DB->new();
 
@@ -335,11 +335,11 @@ The database of language information is not perfect by a long stretch. In partic
 
 =head1 AUTHOR
 
-Earle Martin <EMARTIN@cpan.org>
+Earle Martin <hex@cpan.org>
 
 =over 4 
 
-=item L<http://purl.oclc.org/net/earlemartin/>
+=item L<http://downlode.org/Code/Perl/>
 
 =back
 
@@ -349,9 +349,9 @@ See the credits for L<Locale::Object>.
 
 =head1 LEGAL
 
-Copyright 2003-2004 Earle Martin. All rights reserved.
+Copyright 2003-2007 Earle Martin. All rights reserved.reserved. L<http://purl.org/net/earlemartin/>
 
-This module is released under the same license as Perl itself, and is provided on an "as is" basis. The author makes no warranties of any kind, either expressed or implied, as to the accuracy and/or utility of any results obtained from its use. However, if you do find something wrong with the results, please let the author know. Thanks.
+This module is released under the same license as Perl itself, and is provided on an "as is" basis. No warranty is made of any kind, either expressed or implied, as to the accuracy and/or utility of any results obtained from its use. However, if you do find something wrong with the results, please let the author know. Thanks.
 
 =cut
 
